==> knative-model-6.4.1-sources.jar: io/fabric8/knative/eventing/v1beta1/EventTypeSpecFluentImpl.java <==
package io.fabric8.knative.eventing.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EventTypeSpecFluentImpl<A extends EventTypeSpecFluent<A>> extends BaseFluent<A> implements EventTypeSpecFluent<A>{
  public EventTypeSpecFluentImpl() {
  }
  public EventTypeSpecFluentImpl(EventTypeSpec instance) {
    this.withBroker(instance.getBroker()); 
    this.withDescription(instance.getDescription()); 
    this.withSchema(instance.getSchema()); 
    this.withSchemaData(instance.getSchemaData()); 
    this.withSource(instance.getSource()); 
    this.withType(instance.getType()); 
  }
  private String broker;
  private String description;
  private String schema;
  private String schemaData;
  private String source;
  private String type;
  public String getBroker() {
    return this.broker;
  }
  public A withBroker(String broker) {
    this.broker=broker; return (A) this;
  }
  public Boolean hasBroker() {
    return this.broker != null;
  }
  public String getDescription() {
    return this.description;
  }
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  public Boolean hasDescription() {
    return this.description != null;
  }
  public String getSchema() {
    return this.schema;
  }
  public A withSchema(String schema) {
    this.schema=schema; return (A) this;
  }
  public Boolean hasSchema() {
    return this.schema != null;
  }
  public String getSchemaData() {
    return this.schemaData;
  }
  public A withSchemaData(String schemaData) {
    this.schemaData=schemaData; return (A) this;
  }
  public Boolean hasSchemaData() {
    return this.schemaData != null;
  }
  public String getSource() {
    return this.source;
  }
  public A withSource(String source) {
    this.source=source; return (A) this;
  }
  public Boolean hasSource() {
    return this.source != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EventTypeSpecFluentImpl that = (EventTypeSpecFluentImpl) o;
    if (broker != null ? !broker.equals(that.broker) :that.broker != null) return false;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (schema != null ? !schema.equals(that.schema) :that.schema != null) return false;
    if (schemaData != null ? !schemaData.equals(that.schemaData) :that.schemaData != null) return false;
    if (source != null ? !source.equals(that.source) :that.source != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(broker,  description,  schema,  schemaData,  source,  type,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (broker != null) { sb.append("broker:"); sb.append(broker + ","); }
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (schema != null) { sb.append("schema:"); sb.append(schema + ","); }
    if (schemaData != null) { sb.append("schemaData:"); sb.append(schemaData + ","); }
    if (source != null) { sb.append("source:"); sb.append(source + ","); }
    if (type != null) { sb.append("type:"); sb.append(type); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/v1beta1/EventTypeSpecFluentImpl.java <==
package io.fabric8.knative.eventing.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EventTypeSpecFluentImpl<A extends EventTypeSpecFluent<A>> extends BaseFluent<A> implements EventTypeSpecFluent<A>{
  public EventTypeSpecFluentImpl() {
  }
  public EventTypeSpecFluentImpl(EventTypeSpec instance) {
    if (instance != null) {
      this.withBroker(instance.getBroker());
      this.withDescription(instance.getDescription());
      this.withSchema(instance.getSchema());
      this.withSchemaData(instance.getSchemaData());
      this.withSource(instance.getSource());
      this.withType(instance.getType());
    }
  }
  private String broker;
  private String description;
  private String schema;
  private String schemaData;
  private String source;
  private String type;
  public String getBroker() {
    return this.broker;
  }
  public A withBroker(String broker) {
    this.broker=broker; return (A) this;
  }
  public Boolean hasBroker() {
    return this.broker != null;
  }
  public String getDescription() {
    return this.description;
  }
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  public Boolean hasDescription() {
    return this.description != null;
  }
  public String getSchema() {
    return this.schema;
  }
  public A withSchema(String schema) {
    this.schema=schema; return (A) this;
  }
  public Boolean hasSchema() {
    return this.schema != null;
  }
  public String getSchemaData() {
    return this.schemaData;
  }
  public A withSchemaData(String schemaData) {
    this.schemaData=schemaData; return (A) this;
  }
  public Boolean hasSchemaData() {
    return this.schemaData != null;
  }
  public String getSource() {
    return this.source;
  }
  public A withSource(String source) {
    this.source=source; return (A) this;
  }
  public Boolean hasSource() {
    return this.source != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EventTypeSpecFluentImpl that = (EventTypeSpecFluentImpl) o;
    if (!java.util.Objects.equals(broker, that.broker)) return false;

    if (!java.util.Objects.equals(description, that.description)) return false;

    if (!java.util.Objects.equals(schema, that.schema)) return false;

    if (!java.util.Objects.equals(schemaData, that.schemaData)) return false;

    if (!java.util.Objects.equals(source, that.source)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(broker,  description,  schema,  schemaData,  source,  type,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (broker != null) { sb.append("broker:"); sb.append(broker + ","); }
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (schema != null) { sb.append("schema:"); sb.append(schema + ","); }
    if (schemaData != null) { sb.append("schemaData:"); sb.append(schemaData + ","); }
    if (source != null) { sb.append("source:"); sb.append(source + ","); }
    if (type != null) { sb.append("type:"); sb.append(type); }
    sb.append("}");
    return sb.toString();
  }
  
}
